@@ -3,7 +3,7 @@ package UUID::Generator::PurePerl::Compat;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.80';
 
 use Exporter;
 *import = \&Exporter::import;
@@ -156,89 +156,11 @@ __END__
 
 UUID::Generator::PurePerl::Compat - Compatible interface to Data::UUID
 
-=head1 SYNOPSIS
-
-  use UUID::Generator::PurePerl::Compat;
-  
-  $ug = UUID::Generator::PurePerl::Compat->new();
-  
-  $uuid1 = $ug->create();
-  $uuid2 = $ug->create_from_name(<namespace>, <name>);
-  
-  $res = $ug->compare($uuid1, $uuid2);
-  
-  $str  = $ug->to_string( $uuid );
-  $uuid = $ug->from_string( $str );
-
 =head1 DESCRIPTION
 
-This class provides compatibility layer to L<Data::UUID>.
+This module is going to be marked as *DEPRECATED*.
 
-If you want to know functionality of each method,
-Please refer to L<Data::UUID>.
-
-=head1 METHODS
-
-Following methods and constants are implemented:
-
-=over 2
-
-=item $ug = CLASS->new()
-
-=item $ug->create()
-
-=item $ug->create_bin()
-
-=item $ug->create_hex()
-
-=item $ug->create_b64()
-
-=item $ug->create_from_name(<namespace>, <name>)
-
-=item $ug->create_from_name_bin(<namespace>, <name>)
-
-=item $ug->create_from_name_hex(<namespace>, <name>)
-
-=item $ug->create_from_name_b64(<namespace>, <name>)
-
-=item $ug->to_string(<uuid>)
-
-=item $ug->to_hexstring(<uuid>)
-
-=item $ug->to_b64string(<uuid>)
-
-=item $ug->from_string(<uuid_str>)
-
-=item $ug->from_hexstring(<uuid_str>)
-
-=item $ug->from_b64string(<uuid_str>)
-
-=item $ug->compare(<uuid1>, <uuid2>)
-
-=item NameSpace_DNS()
-
-=item NameSpace_URL()
-
-=item NameSpace_OID()
-
-=item NameSpace_X500()
-
-=back
-
-=head1 NOTICE
-
-As written in L<UUID::Object/"NOTICE ABOUT PORTABILITY">,
-binary and Base64 form of UUIDs generated by L<Data::UUID>
-depend on endian of platform.
-
-This module inherits that behavior of L<Data::UUID>,
-so UUIDs generated with those methods,
-such like C<create_bin()> and C<create_from_name_b64()>,
-may not be compatible over machines.
-
-=head1 SEE ALSO
-
-L<Data::UUID>, L<UUID::Generator::PurePerl>.
+Do not use this module in your applications / modules.
 
 =head1 AUTHOR
 
